@@ -140,7 +140,11 @@
  *	Added a second patch to remove the pidfile as part of the
  *	termination cleanup sequence.  This minimizes the potential for
  *	conflicting pidfiles causing immediate termination at boot time.
- *	
+ *
+ * Sun May 12 12:18:21 MET DST 1996:  Martin Schulze
+ *	Corrected incorrect/insecure use of strpbrk for a not necessarily
+ *	null-terminated buffer.  Used a patch from Chris Hanson
+ *	(cph@martigny.ai.mit.edu), thanks.
  */
 
 
@@ -439,6 +443,7 @@ static void LogLine(char *ptr, int len)
 	auto int idx = 0;
 	static int index = 0;
 	auto char *nl;
+	auto char *pend = ptr + len;
 	static char line[LOG_LINE_LENGTH],
 		    eline[LOG_LINE_LENGTH];
 
@@ -467,8 +472,10 @@ static void LogLine(char *ptr, int len)
 		memset(line, '\0', sizeof(line));
 	
 	while (len) {
-		nl = strpbrk(ptr, "\r\n"); /* Find first line terminator */
-		if (nl) {
+		for (nl = ptr; nl < pend; nl += 1)
+			if ((*nl == '\n') || (*nl == '\r'))
+				break;
+		if (nl != pend) {
 			len -= nl - ptr + 1;
 			strncat(line, ptr, nl - ptr);
 			ptr = nl + 1;
