@@ -730,11 +730,14 @@ int main(argc, argv)
 		 * we want to distribute good software.  Joey
 		 */
 		hent = gethostbyname(LocalHostName);
-		sprintf(LocalHostName, "%s", hent->h_name);
-		if ( (p = index(LocalHostName, '.')) )
+		if (hent != NULL)
 		{
-			*p++ = '\0';
-			LocalDomain = p;
+			sprintf(LocalHostName, "%s", hent->h_name);
+			if ( (p = index(LocalHostName, '.')) )
+			{	
+				*p++ = '\0';
+				LocalDomain = p;
+			}
 		}
 	}
 
